===========================
 API Reference
===========================

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 2

    kombu.connection
    kombu.simple
    kombu.messaging
    kombu.entity
    kombu.common
    kombu.mixins
    kombu.clocks
    kombu.compat
    kombu.pidbox
    kombu.exceptions
    kombu.transport
    kombu.transport.pyamqplib
    kombu.transport.librabbitmq
    kombu.transport.pypika
    kombu.transport.memory
    kombu.transport.pyredis
    kombu.transport.beanstalk
    kombu.transport.mongodb
    kombu.transport.pycouchdb
    kombu.transport.SQS
    kombu.transport.base
    kombu.transport.virtual
    kombu.transport.virtual.exchange
    kombu.transport.virtual.scheduling
    kombu.serialization
    kombu.compression
    kombu.pools
    kombu.abstract
    kombu.syn
    kombu.utils
    kombu.utils.limits
    kombu.utils.compat
    kombu.utils.debug
    kombu.utils.encoding
    kombu.utils.functional
    kombu.utils.finalize
    kombu.utils.log
